@@ -3,13 +3,13 @@
 {%- match func.return_type() -%}
 {%- when Some with (return_type) %}
 
-fun {{ func.name()|fn_name_kt }}({%- call kt::arg_list_decl(func) -%}): {{ return_type|type_kt }} {
+fun {{ func.name()|fn_name }}({%- call kt::arg_list_decl(func) -%}): {{ return_type|type_name }} {
     val _retval = {% call kt::to_ffi_call(func) %}
-    return {{ "_retval"|lift_kt(return_type) }}
+    return {{ "_retval"|lift_var(return_type) }}
 }
 
 {% when None -%}
 
-fun {{ func.name()|fn_name_kt }}({% call kt::arg_list_decl(func) %}) =
+fun {{ func.name()|fn_name }}({% call kt::arg_list_decl(func) %}) =
     {% call kt::to_ffi_call(func) %}
 {% endmatch %}
