@@ -112,7 +112,7 @@ impl Type {
             Type::Sequence(t) => format!("Sequence{}", t.canonical_name()),
             Type::Map(t) => format!("Map{}", t.canonical_name()),
             // A type that exists externally.
-            Type::External { name, .. } | Type::Wrapped { name, .. } => format!("Type{}", name),
+            Type::External { name, .. } | Type::Wrapped { name, .. } => name.to_owned(),
         }
     }
 }
