@@ -4,15 +4,16 @@
 // If the caller's struct does not match the shape and types declared in the UDL then the rust
 // compiler will complain with a type error.
 //
-// We define a unit-struct to implement the trait to sidestep Rust's orphan rule (ADR-0006)
+// We define a unit-struct to implement the trait to sidestep Rust's orphan rule (ADR-0006). It's
+// public so other crates can refer to it via an `[External='crate'] typedef`
 #}
-struct {{ rec.type_()|ffi_converter_name }};
+pub struct {{ rec.type_()|ffi_converter_name }};
 
 #[doc(hidden)]
 impl uniffi::RustBufferFfiConverter for {{ rec.type_()|ffi_converter_name }} {
     type RustType = {{ rec.name() }};
 
-    fn write(obj: {{ rec.name() }}, buf: &mut Vec<u8>) {
+    fn write(obj: {{ rec.name() }}, buf: &mut std::vec::Vec<u8>) {
         // If the provided struct doesn't match the fields declared in the UDL, then
         // the generated code here will fail to compile with somewhat helpful error.
         {%- for field in rec.fields() %}
